/***************************************************************************
                          guibutton.h  -  description
                             -------------------
    begin                : Tue Jun 15 2004
    copyright            : (C) 2004 by Harald Krippel
    email                : harald@hte-develop.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUIBUTTON_H
#define GUIBUTTON_H

/**
  *@author Harald Krippel
  */

#include <plib/pu.h>

/*!

 This Class is the glue between PLIB puButton and QCake.

*/
class GUIButton : public puButton  {
public: 
	GUIButton(int minx, int miny, const char *l);
  void setText(const char *text);
	~GUIButton();
private:
  char legendtext[256];
};
#endif
